{% load static sekizai_tags sass_tags %}{% spaceless %}

{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "djng.forms" %}

{% block dialog_form %}
{% if stylesheet_url %}{% addtoblock "css" %}<link href="{{ stylesheet_url }}" rel="stylesheet" type="text/css" />{% endaddtoblock %}{% endif %}
	{% with instance_css_classes=instance.css_classes instance_inline_styles=instance.inline_styles instance_content=instance.glossary.link_content%}
	<button ng-click="do(prepare()).then(update()).then(showOK()).then(emit('shop.checkout.digest')).then(delay(333)).then(nextStep).catch(scrollToRejected()).finally(restore())" ng-disabled="isDisabled()" {% if instance_css_classes %} class="{{ instance_css_classes }}"{% endif %}{% if instance_inline_styles %} style="{{ instance_inline_styles }}"{% endif %}>
		{{ icon_left }}{{ instance_content }}{{ icon_right }}
	</button>
	{% endwith %}
{% endblock %}

{% endspaceless %}
