{% extends "./anonymous-base.html" %}
{% load i18n %}

{% block form-title %}{% blocktrans %}New password for '{{ user_name }}'{% endblocktrans %}{% endblock %}

{% block form-content %}
<form name="{{ form_name }}" djng-endpoint="." role="form" novalidate>
	{% include "./form-messages.html" %}

	<p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
	<label class="control-label">{% trans "New Password" %}</label>
	<div style="margin-bottom: 10px" class="input-group">
		<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
		<input type="password" class="form-control" name="new_password1" ng-model="form_data.new_password1" ng-required="true" placeholder="{% trans 'New password' %}" />
	</div>

	<label class="control-label">{% trans "Confirm Password" %}</label>
	<div style="margin-bottom: 20px" class="input-group">
		<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
		<input type="password" class="form-control" name="new_password2" ng-model="form_data.new_password2" ng-required="true" placeholder="{% trans 'Confirm password' %}" />
	</div>

	<div class="input-group">
		<button type="button" ng-click="{% include "./proceed-with.html" %}" class="btn btn-primary">{% trans 'Change my password' %}</button>
	</div>
</form>
{% endblock form-content %}
