{% load i18n static sekizai_tags %}

{% addtoblock "js" %}<script src="{% static 'djng/js/django-angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% add_data "ng-requires" "djng.forms" %}

{% if customer.is_authenticated %}
<div class="panel panel-info">
	<div class="panel-heading">
		<div class="panel-title">{% block form-title %}Panel Title{% endblock %}</div>
	</div>

	<div class="panel-body">
	{% block form-content %}{% endblock %}
	</div>
</div>
{% else %}
<div class="bg-warning">{% trans "This page shall only be reachable by authenticated users" %}</div>
{% endif %}
