@import "variables";
@import "bootstrap-sass/assets/stylesheets/bootstrap";
@import "font-awesome/scss/font-awesome";
@import "django-angular";

.breadcrumb {
	margin-top: 20px;

	>li + li::before {
		// fixes https://github.com/twbs/bootstrap-sass/issues/919
		content: "/";
	}
}

// use it to remove borders in tables
table tr {
	&.no-border {
		td, th {
			border-top-style: hidden;
		}
	}
	&.double-border {
		border-top-style: double;
	}
	td.no-border, th.no-border {
		border-top-style: hidden;
	}
	td.double-border, th.double-border {
		border-top-style: double;
	}
	td.vertical-align-middle {
		vertical-align: middle;
	}
}

.panel {
	ul {
		padding-left: 0;
		list-style: none;
	}
}

shop-auth-form {
	.ng-invalid.ng-touched {
		border-color: #e9322d;
	}
}

.shop-form-error {
	position: absolute;
	list-style: none;
	top: 0;
	right: 5px;
	li {
		color: #e9322d;
		font-weight: bold;
		white-space: nowrap;
		padding-left: 8px;
		padding-right: 4px;
		border: 1px dotted #e9322d;
		border-radius: 3px;
		background: #f2dede;
		opacity: 0.85;
		&::before {
			content: "\2716";
			margin-right: 10px;
		}
	}
}
