{% extends "./authenticated-base.html" %}
{% load i18n %}

{% block form-title %}{% trans "Change Password" %}{% endblock %}

{% block form-content %}
<form name="{{ form_name }}" djng-endpoint="{% url 'shop:password-change' %}" role="form" novalidate>
	{% include "./form-messages.html" %}

	<div class="form-group has-feedback" style="margin-bottom: 25px;">
		<label class="control-label">{% trans "New Password" %}</label>
		<div class="input-group">
			<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
			<input type="password" class="form-control" name="new_password1" ng-model="form_data.new_password1" placeholder="{% trans 'New Password' %}" ng-required="true">
		</div>
		<ul ng-show="change_form.new_password1.$error.rejected && change_form.new_password1.$pristine" class="shop-form-error" ng-cloak>
			<li ng-bind="change_form.new_password1.$message"></li>
		</ul>
	</div>

	<div class="form-group has-feedback" style="margin-bottom: 25px;">
		<label class="control-label">{% trans "Confirm Password" %}</label>
		<div class="input-group">
			<span class="input-group-addon"><i class="fa fa-key fa-fw"></i></span>
			<input type="password" class="form-control" name="new_password2" ng-model="form_data.new_password2" placeholder="{% trans 'Confirm Password' %}" ng-required="true">
		</div>
		<ul ng-show="change_form.new_password2.$error.rejected && change_form.new_password2.$pristine" class="shop-form-error" ng-cloak>
			<li ng-bind="change_form.new_password2.$message"></li>
		</ul>
	</div>

	<div class="form-group">
		<button type="button" ng-disabled="isDisabled()" ng-click="{% include "./proceed-with.html" with delay=1500 %}" class="btn btn-primary">{% trans "Change Password" %}</button>
	</div>
</form>
{% endblock form-content %}
